=========================
get bitshares price
=========================

.. image:: https://bitsharestalk.org/BitSharesFinalTM200.png
   :target: https://bitsharestalk.org

This project provides bitshares price

Project Setup
=============

Quick Start
------------
#. Install::

       $ python setup.py install --user


Configuration
------------
todo

Supported Python Versions
=========================

supports the following versions out of the box:

* CPython 2.6, 2.7, 3.3
* PyPy 1.9

CPython 3.0-3.2 may also work but are at this point unsupported. PyPy 2.0.2 is known to work but is not run on Travis-CI.

Jython_ and IronPython_ may also work, but have not been tested. If there is interest in support for these alternative implementations, please open a feature request!

.. _Jython: http://jython.org/
.. _IronPython: http://ironpython.net/

Licenses
========
The code which makes up this project is licensed under the MIT/X11 license. Feel free to use it in your free software/open-source or proprietary projects.

Issues
======

Please report any bugs or requests that you have using the GitHub issue tracker!

Authors
=======

* Alt
